# Summary of 3 files

### needs_group_size_reduction in 3 LFNs

| Transform | LFN | Job ID | Site | Peak Mem | Log URL(s) | Occurrences |
| --------- | --- | ------ | ---- | -------- | ---------- | ----------- |
| `249642` | `LFN:/lhcb/MC/2016/ALLRADIATIVE.STRIP.DST/00154270/0000/00154270_00000011_1.allradiative.strip.dst` | 966294203 | **LCG.CERN.cern** (3) | 2.7 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000004) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000002) | 3 / 3 |
|  | `LFN:/lhcb/MC/2016/ALLRADIATIVE.STRIP.DST/00154270/0000/00154270_00000012_1.allradiative.strip.dst` | 966294203 | **LCG.CERN.cern** (3) | 2.7 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000004) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000002) | 3 / 3 |
|  | `LFN:/lhcb/MC/2016/ALLRADIATIVE.STRIP.DST/00154270/0000/00154270_00000013_1.allradiative.strip.dst` | 966294203 | **LCG.CERN.cern** (3) | 2.7 GiB | [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000004) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000003) [here](https://lhcb-productions.web.cern.ch/logs/?lfn=%2Flhcb%2FMC%2F2016%2FLOG%2F00249642%2F0000&task_name=00000002) | 3 / 3 |
